apiVersion: v1
kind: PersistentVolume
metadata:
  name: {{ image }}
  labels:
    solution: {{ solution }}
    product:  {{ product }}
spec:
  capacity: 
    storage: 20Gi
  accessModes:
    - ReadWriteOnce
  rbd:
    monitors:
    {% for monitor in groups['mon_hosts'] -%}
      - {{ hostvars[monitor]['ansible_' + interface].ipv4.address }}
    {% endfor -%}
    pool: {{ pool }}
    image: {{ image }}
    fsType: xfs
    readOnly: false
    # secretRef:
    #   name: ceph-secret
    keyring: /etc/ceph/ceph.client.admin.keyring
    user: admin