#
# kubernetes kube-scheduler config
#

KUBE_SCHEDULER_ADDRESS="--address=0.0.0.0"
KUBE_SCHEDULER_KUBECONFIG="--kubeconfig=/etc/kubernetes/kubeconfig/kube-scheduler.kubeconfig"
KUBE_SCHEDULER_LEADER_ELECT="--leader-elect=true"
KUBE_SCHEDULER_ARGS=""
